<?php
declare(strict_types=1);

/**
 * This file is part of phpDocumentor.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 *
 * @author    Mike van Riel <mike.vanriel@naenius.com>
 * @copyright 2010-2018 Mike van Riel / Naenius (http://www.naenius.com)
 * @license   http://www.opensource.org/licenses/mit-license.php MIT
 * @link      http://phpdoc.org
 */

namespace phpDocumentor\Descriptor\Builder\Reflector\Tags;

use phpDocumentor\Descriptor\Builder\Reflector\AssemblerAbstract;
use phpDocumentor\Descriptor\Tag\LinkDescriptor;
use phpDocumentor\Reflection\DocBlock\Tags\Link;

/**
 * Constructs a new descriptor from the Reflector for an `@link` tag.
 *
 * This object will read the reflected information for the `@link` tag and create a {@see LinkDescriptor} object that
 * can be used in the rest of the application and templates.
 */
class LinkAssembler extends AssemblerAbstract
{
    /**
     * Creates a new Descriptor from the given Reflector.
     *
     * @param Link $data
     *
     * @return LinkDescriptor
     */
    public function create($data)
    {
        $descriptor = new LinkDescriptor($data->getName());
        $descriptor->setLink($data->getLink());
        $descriptor->setDescription($data->getDescription());

        return $descriptor;
    }
}
